More inclusive language fixes

Bug: 161896447
Bug: 161850439
Bug: 161336379
Test: art/test.py --host
Change-Id: I1519e22d40cb28f243dd75b12d455cfa844726fc
diff --git a/test/004-JniTest/src/Main.java b/test/004-JniTest/src/Main.java
index f94dcf6..3341bbd 100644
--- a/test/004-JniTest/src/Main.java
+++ b/test/004-JniTest/src/Main.java
@@ -246,14 +246,14 @@
         void a();
     }
 
-    private static class DummyInvocationHandler implements InvocationHandler {
+    private static class MinimalInvocationHandler implements InvocationHandler {
         public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
             return null;
         }
     }
 
     private static void testProxyGetMethodID() {
-        InvocationHandler handler = new DummyInvocationHandler();
+        InvocationHandler handler = new MinimalInvocationHandler();
         SimpleInterface proxy =
                 (SimpleInterface) Proxy.newProxyInstance(SimpleInterface.class.getClassLoader(),
                         new Class<?>[] {SimpleInterface.class}, handler);
diff --git a/test/008-exceptions/src-multidex/MultiDexBadInitWrapper2.java b/test/008-exceptions/src-multidex/MultiDexBadInitWrapper2.java
index f3953bd..a66d818 100644
--- a/test/008-exceptions/src-multidex/MultiDexBadInitWrapper2.java
+++ b/test/008-exceptions/src-multidex/MultiDexBadInitWrapper2.java
@@ -15,9 +15,9 @@
  */
 
 class MultiDexBadInitWrapper2 {
-    public static void setDummy(int value) {
+    public static void setIntField(int value) {
         if (doThrow) { throw new Error(); }
-        MultiDexBadInit.dummy = value;
+        MultiDexBadInit.intField = value;
     }
 
     public static boolean doThrow = false;
diff --git a/test/008-exceptions/src/Main.java b/test/008-exceptions/src/Main.java
index 008576a..0ba5f80 100644
--- a/test/008-exceptions/src/Main.java
+++ b/test/008-exceptions/src/Main.java
@@ -23,7 +23,7 @@
 
 // A class that throws BadError during static initialization.
 class BadInit {
-    static int dummy;
+    static int intField;
     static {
         System.out.println("Static Init");
         if (true) {
@@ -41,7 +41,7 @@
 
 // A class that throws BadErrorNoStringInit during static initialization.
 class BadInitNoStringInit {
-    static int dummy;
+    static int intField;
     static {
         System.out.println("Static BadInitNoStringInit");
         if (true) {
@@ -52,7 +52,7 @@
 
 // A class that throws BadError during static initialization, serving as a super class.
 class BadSuperClass {
- static int dummy;
+ static int intField;
  static {
      System.out.println("BadSuperClass Static Init");
      if (true) {
@@ -104,7 +104,7 @@
     private static void exceptionsRethrowClassInitFailure() {
         try {
             try {
-                BadInit.dummy = 1;
+                BadInit.intField = 1;
                 throw new IllegalStateException("Should not reach here.");
             } catch (BadError e) {
                 System.out.println(e);
@@ -113,7 +113,7 @@
             // Check if it works a second time.
 
             try {
-                BadInit.dummy = 1;
+                BadInit.intField = 1;
                 throw new IllegalStateException("Should not reach here.");
             } catch (NoClassDefFoundError e) {
                 System.out.println(e);
@@ -127,7 +127,7 @@
     private static void exceptionsRethrowClassInitFailureNoStringInit() {
         try {
             try {
-                BadInitNoStringInit.dummy = 1;
+                BadInitNoStringInit.intField = 1;
                 throw new IllegalStateException("Should not reach here.");
             } catch (BadErrorNoStringInit e) {
                 System.out.println(e);
@@ -136,7 +136,7 @@
             // Check if it works a second time.
 
             try {
-                BadInitNoStringInit.dummy = 1;
+                BadInitNoStringInit.intField = 1;
                 throw new IllegalStateException("Should not reach here.");
             } catch (NoClassDefFoundError e) {
                 System.out.println(e);
@@ -150,7 +150,7 @@
     private static void exceptionsForSuperClassInitFailure() {
         try {
             // Resolve DerivedFromBadSuperClass.
-            BadSuperClass.dummy = 1;
+            BadSuperClass.intField = 1;
             throw new IllegalStateException("Should not reach here.");
         } catch (BadError e) {
             System.out.println(e);
@@ -181,7 +181,7 @@
 
     private static void exceptionsInMultiDex() {
         try {
-            MultiDexBadInit.dummy = 1;
+            MultiDexBadInit.intField = 1;
             throw new IllegalStateException("Should not reach here.");
         } catch (Error e) {
             System.out.println(e);
@@ -194,7 +194,7 @@
         // wrapped in NoClassDefFoundError but the exception
         // from wrapper 2 would have been unwrapped.
         try {
-            MultiDexBadInitWrapper1.setDummy(1);
+            MultiDexBadInitWrapper1.setIntField(1);
             throw new IllegalStateException("Should not reach here.");
         } catch (NoClassDefFoundError ncdfe) {
             System.out.println(ncdfe);
@@ -203,7 +203,7 @@
             t.printStackTrace(System.out);
         }
         try {
-            MultiDexBadInitWrapper2.setDummy(1);
+            MultiDexBadInitWrapper2.setIntField(1);
             throw new IllegalStateException("Should not reach here.");
         } catch (NoClassDefFoundError ncdfe) {
             System.out.println(ncdfe);
diff --git a/test/008-exceptions/src/MultiDexBadInit.java b/test/008-exceptions/src/MultiDexBadInit.java
index e3ebb9c..e060323 100644
--- a/test/008-exceptions/src/MultiDexBadInit.java
+++ b/test/008-exceptions/src/MultiDexBadInit.java
@@ -15,7 +15,7 @@
  */
 
 class MultiDexBadInit {
-    static int dummy;
+    static int intField;
     static {
         System.out.println("MultiDexBadInit Static Init");
         if (true) {
diff --git a/test/008-exceptions/src/MultiDexBadInitWrapper1.java b/test/008-exceptions/src/MultiDexBadInitWrapper1.java
index 059e6a3..563e2c3 100644
--- a/test/008-exceptions/src/MultiDexBadInitWrapper1.java
+++ b/test/008-exceptions/src/MultiDexBadInitWrapper1.java
@@ -15,9 +15,9 @@
  */
 
 class MultiDexBadInitWrapper1 {
-    public static void setDummy(int value) {
+    public static void setIntField(int value) {
         if (doThrow) { throw new Error(); }
-        MultiDexBadInit.dummy = value;
+        MultiDexBadInit.intField = value;
     }
 
     public static boolean doThrow = false;
diff --git a/test/046-reflect/src/Main.java b/test/046-reflect/src/Main.java
index 6d6cc13..6cd137d 100644
--- a/test/046-reflect/src/Main.java
+++ b/test/046-reflect/src/Main.java
@@ -502,12 +502,12 @@
     /*
      * Test some generic type stuff.
      */
-    public List<String> dummy;
+    public List<String> stringList;
     public Map<Integer,String> fancyMethod(ArrayList<String> blah) { return null; }
     public static void checkGeneric() {
         Field field;
         try {
-            field = Main.class.getField("dummy");
+            field = Main.class.getField("stringList");
         } catch (NoSuchFieldException nsfe) {
             throw new RuntimeException(nsfe);
         }
@@ -561,8 +561,8 @@
     public static void checkUnique() {
         Field field1, field2;
         try {
-            field1 = Main.class.getField("dummy");
-            field2 = Main.class.getField("dummy");
+            field1 = Main.class.getField("stringList");
+            field2 = Main.class.getField("stringList");
         } catch (NoSuchFieldException nsfe) {
             throw new RuntimeException(nsfe);
         }
diff --git a/test/083-compiler-regressions/src/Main.java b/test/083-compiler-regressions/src/Main.java
index 285c360..9de3f5a 100644
--- a/test/083-compiler-regressions/src/Main.java
+++ b/test/083-compiler-regressions/src/Main.java
@@ -277,13 +277,13 @@
         sum += foo.getBar0();
         foo.setBar5ReturnBarArg(1,2,3,4,sum);
         sum += foo.getBar0();
-        foo.setBar2ReturnDummyArg1(1,sum);
+        foo.setBar2ReturnArg1(1,sum);
         sum += foo.getBar0();
-        foo.setBar3ReturnDummyArg2(1,2,sum);
+        foo.setBar3ReturnArg2(1,2,sum);
         sum += foo.getBar0();
-        foo.setBar4ReturnDummyArg3(1,2,3,sum);
+        foo.setBar4ReturnArg3(1,2,3,sum);
         sum += foo.getBar0();
-        foo.setBar5ReturnDummyArg4(1,2,3,4,sum);
+        foo.setBar5ReturnArg4(1,2,3,4,sum);
         sum += foo.getBar0();
         Foo nullFoo = Foo.getNullFoo();
         try {
@@ -337,22 +337,22 @@
             sum += 10 * 404;
         }
         try {
-            nullFoo.setBar2ReturnDummyArg1(1, sum);
+            nullFoo.setBar2ReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 11 * 404;
         }
         try {
-            nullFoo.setBar3ReturnDummyArg2(1, 2, sum);
+            nullFoo.setBar3ReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 12 * 404;
         }
         try {
-            nullFoo.setBar4ReturnDummyArg3(1, 2, 3, sum);
+            nullFoo.setBar4ReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 13 * 404;
         }
         try {
-            nullFoo.setBar5ReturnDummyArg4(1, 2, 3, 4, sum);
+            nullFoo.setBar5ReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 14 * 404;
         }
@@ -369,7 +369,7 @@
     static void setterTestWithReturnArgUseReturn() {
         Foo foo = new Foo();
         int sum = foo.getBar0();
-        int sumDummy = 0;
+        int sumTally = 0;
         sum += foo.getBar0();
         Foo foo2 = foo.setBar1ReturnThis(sum);
         sum += foo2.getBar0();
@@ -391,13 +391,13 @@
         sum += foo.getBar0();
         sum += foo.setBar5ReturnBarArg(1,2,3,4,sum);
         sum += foo.getBar0();
-        sumDummy += foo.setBar2ReturnDummyArg1(1,sum);
+        sumTally += foo.setBar2ReturnArg1(1,sum);
         sum += foo.getBar0();
-        sumDummy += foo.setBar3ReturnDummyArg2(1,2,sum);
+        sumTally += foo.setBar3ReturnArg2(1,2,sum);
         sum += foo.getBar0();
-        sumDummy += foo.setBar4ReturnDummyArg3(1,2,3,sum);
+        sumTally += foo.setBar4ReturnArg3(1,2,3,sum);
         sum += foo.getBar0();
-        sumDummy += foo.setBar5ReturnDummyArg4(1,2,3,4,sum);
+        sumTally += foo.setBar5ReturnArg4(1,2,3,4,sum);
         sum += foo.getBar0();
         Foo nullFoo = Foo.getNullFoo();
         try {
@@ -451,34 +451,34 @@
             sum += 10 * 404;
         }
         try {
-            sumDummy += nullFoo.setBar2ReturnDummyArg1(1, sum);
+            sumTally += nullFoo.setBar2ReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 11 * 404;
         }
         try {
-            sumDummy += nullFoo.setBar3ReturnDummyArg2(1, 2, sum);
+            sumTally += nullFoo.setBar3ReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 12 * 404;
         }
         try {
-            sumDummy += nullFoo.setBar4ReturnDummyArg3(1, 2, 3, sum);
+            sumTally += nullFoo.setBar4ReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 13 * 404;
         }
         try {
-            sumDummy += nullFoo.setBar5ReturnDummyArg4(1, 2, 3, 4, sum);
+            sumTally += nullFoo.setBar5ReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 14 * 404;
         }
         int expected = (1234 << 10) * 3 * 3 * 3 * 3 * 3 + 404 * (15 * 14 / 2);
-        int expectedDummy = 5 * 4 / 2;
-        if (sum == expected && sumDummy == expectedDummy) {
+        int expectedTally = 5 * 4 / 2;
+        if (sum == expected && sumTally == expectedTally) {
             System.out.println("setterTestWithReturnArgUseReturn passes");
         }
         else {
             System.out.println("setterTestWithReturnArgUseReturn fails: " + sum +
-                               " (expecting " + expected + "), sumDummy = " + sumDummy +
-                               "(expecting " + expectedDummy + ")");
+                               " (expecting " + expected + "), sumTally = " + sumTally +
+                               "(expecting " + expectedTally + ")");
         }
     }
 
@@ -514,21 +514,21 @@
         sum += foo.wideGetBar0();
         foo.wideSetBar5iReturnBarArg(1,2,3,4,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar2ReturnDummyArg1(1,sum);
+        foo.wideSetBar2ReturnArg1(1,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar3ReturnDummyArg2(1,2,sum);
+        foo.wideSetBar3ReturnArg2(1,2,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar4ReturnDummyArg3(1,2,3,sum);
+        foo.wideSetBar4ReturnArg3(1,2,3,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar5ReturnDummyArg4(1,2,3,4,sum);
+        foo.wideSetBar5ReturnArg4(1,2,3,4,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar2iReturnDummyArg1(1,sum);
+        foo.wideSetBar2iReturnArg1(1,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar3iReturnDummyArg2(1,2,sum);
+        foo.wideSetBar3iReturnArg2(1,2,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar4iReturnDummyArg3(1,2,3,sum);
+        foo.wideSetBar4iReturnArg3(1,2,3,sum);
         sum += foo.wideGetBar0();
-        foo.wideSetBar5iReturnDummyArg4(1,2,3,4,sum);
+        foo.wideSetBar5iReturnArg4(1,2,3,4,sum);
         sum += foo.wideGetBar0();
         Foo nullFoo = Foo.getNullFoo();
         try {
@@ -602,42 +602,42 @@
             sum += 14 * 404;
         }
         try {
-            nullFoo.wideSetBar2ReturnDummyArg1(1, sum);
+            nullFoo.wideSetBar2ReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 15 * 404;
         }
         try {
-            nullFoo.wideSetBar3ReturnDummyArg2(1, 2, sum);
+            nullFoo.wideSetBar3ReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 16 * 404;
         }
         try {
-            nullFoo.wideSetBar4ReturnDummyArg3(1, 2, 3, sum);
+            nullFoo.wideSetBar4ReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 17 * 404;
         }
         try {
-            nullFoo.wideSetBar5ReturnDummyArg4(1, 2, 3, 4, sum);
+            nullFoo.wideSetBar5ReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 18 * 404;
         }
         try {
-            nullFoo.wideSetBar2iReturnDummyArg1(1, sum);
+            nullFoo.wideSetBar2iReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 19 * 404;
         }
         try {
-            nullFoo.wideSetBar3iReturnDummyArg2(1, 2, sum);
+            nullFoo.wideSetBar3iReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 20 * 404;
         }
         try {
-            nullFoo.wideSetBar4iReturnDummyArg3(1, 2, 3, sum);
+            nullFoo.wideSetBar4iReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 21 * 404;
         }
         try {
-            nullFoo.wideSetBar5iReturnDummyArg4(1, 2, 3, 4, sum);
+            nullFoo.wideSetBar5iReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 22 * 404;
         }
@@ -654,7 +654,7 @@
     static void wideSetterTestWithReturnArgUseReturn() {
         Foo foo = new Foo();
         long sum = foo.wideGetBar0();
-        long sumDummy = 0;
+        long sumTally = 0;
         sum += foo.wideGetBar0();
         Foo foo2 = foo.wideSetBar1ReturnThis(sum);
         sum += foo2.wideGetBar0();
@@ -684,21 +684,21 @@
         sum += foo.wideGetBar0();
         sum += foo.wideSetBar5iReturnBarArg(1,2,3,4,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar2ReturnDummyArg1(1,sum);
+        sumTally += foo.wideSetBar2ReturnArg1(1,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar3ReturnDummyArg2(1,2,sum);
+        sumTally += foo.wideSetBar3ReturnArg2(1,2,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar4ReturnDummyArg3(1,2,3,sum);
+        sumTally += foo.wideSetBar4ReturnArg3(1,2,3,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar5ReturnDummyArg4(1,2,3,4,sum);
+        sumTally += foo.wideSetBar5ReturnArg4(1,2,3,4,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar2iReturnDummyArg1(1,sum);
+        sumTally += foo.wideSetBar2iReturnArg1(1,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar3iReturnDummyArg2(1,2,sum);
+        sumTally += foo.wideSetBar3iReturnArg2(1,2,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar4iReturnDummyArg3(1,2,3,sum);
+        sumTally += foo.wideSetBar4iReturnArg3(1,2,3,sum);
         sum += foo.wideGetBar0();
-        sumDummy += foo.wideSetBar5iReturnDummyArg4(1,2,3,4,sum);
+        sumTally += foo.wideSetBar5iReturnArg4(1,2,3,4,sum);
         sum += foo.wideGetBar0();
         Foo nullFoo = Foo.getNullFoo();
         try {
@@ -772,54 +772,54 @@
             sum += 14 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar2ReturnDummyArg1(1, sum);
+            sumTally += nullFoo.wideSetBar2ReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 15 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar3ReturnDummyArg2(1, 2, sum);
+            sumTally += nullFoo.wideSetBar3ReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 16 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar4ReturnDummyArg3(1, 2, 3, sum);
+            sumTally += nullFoo.wideSetBar4ReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 17 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar5ReturnDummyArg4(1, 2, 3, 4, sum);
+            sumTally += nullFoo.wideSetBar5ReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 18 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar2iReturnDummyArg1(1, sum);
+            sumTally += nullFoo.wideSetBar2iReturnArg1(1, sum);
         } catch(NullPointerException npe) {
             sum += 19 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar3iReturnDummyArg2(1, 2, sum);
+            sumTally += nullFoo.wideSetBar3iReturnArg2(1, 2, sum);
         } catch(NullPointerException npe) {
             sum += 20 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar4iReturnDummyArg3(1, 2, 3, sum);
+            sumTally += nullFoo.wideSetBar4iReturnArg3(1, 2, 3, sum);
         } catch(NullPointerException npe) {
             sum += 21 * 404;
         }
         try {
-            sumDummy += nullFoo.wideSetBar5iReturnDummyArg4(1, 2, 3, 4, sum);
+            sumTally += nullFoo.wideSetBar5iReturnArg4(1, 2, 3, 4, sum);
         } catch(NullPointerException npe) {
             sum += 22 * 404;
         }
         long expected = (1234L << 14) * 3 * 3 * 3 * 3 * 3 * 3 * 3 * 3 * 3  + 404 * (23 * 22 / 2);
-        long expectedDummy = 2 * (5 * 4 / 2);
-        if (sum == expected && sumDummy == expectedDummy) {
+        long expectedTally = 2 * (5 * 4 / 2);
+        if (sum == expected && sumTally == expectedTally) {
             System.out.println("wideSetterTestWithReturnArgUseReturn passes");
         }
         else {
             System.out.println("wideSetterTestWithReturnArgUseReturn fails: " + sum +
-                               " (expecting " + expected + "), sumDummy = " + sumDummy +
-                               "(expecting " + expectedDummy + ")");
+                               " (expecting " + expected + "), sumTally = " + sumTally +
+                               "(expecting " + expectedTally + ")");
         }
     }
 
@@ -9632,51 +9632,51 @@
         lbar = a5;
         return a5;
     }
-    public int setBar2ReturnDummyArg1(int a1, int a2) {
+    public int setBar2ReturnArg1(int a1, int a2) {
         bar = a2;
         return a1;
     }
-    public int setBar3ReturnDummyArg2(int a1, int a2, int a3) {
+    public int setBar3ReturnArg2(int a1, int a2, int a3) {
         bar = a3;
         return a2;
     }
-    public int setBar4ReturnDummyArg3(int a1, int a2, int a3, int a4) {
+    public int setBar4ReturnArg3(int a1, int a2, int a3, int a4) {
         bar = a4;
         return a3;
     }
-    public int setBar5ReturnDummyArg4(int a1, int a2, int a3, int a4, int a5) {
+    public int setBar5ReturnArg4(int a1, int a2, int a3, int a4, int a5) {
         bar = a5;
         return a4;
     }
-    public long wideSetBar2ReturnDummyArg1(long a1, long a2) {
+    public long wideSetBar2ReturnArg1(long a1, long a2) {
         lbar = a2;
         return a1;
     }
-    public long wideSetBar3ReturnDummyArg2(long a1, long a2, long a3) {
+    public long wideSetBar3ReturnArg2(long a1, long a2, long a3) {
         lbar = a3;
         return a2;
     }
-    public long wideSetBar4ReturnDummyArg3(long a1, long a2, long a3, long a4) {
+    public long wideSetBar4ReturnArg3(long a1, long a2, long a3, long a4) {
         lbar = a4;
         return a3;
     }
-    public long wideSetBar5ReturnDummyArg4(long a1, long a2, long a3, long a4, long a5) {
+    public long wideSetBar5ReturnArg4(long a1, long a2, long a3, long a4, long a5) {
         lbar = a5;
         return a4;
     }
-    public int wideSetBar2iReturnDummyArg1(int a1, long a2) {
+    public int wideSetBar2iReturnArg1(int a1, long a2) {
         lbar = a2;
         return a1;
     }
-    public int wideSetBar3iReturnDummyArg2(int a1, int a2, long a3) {
+    public int wideSetBar3iReturnArg2(int a1, int a2, long a3) {
         lbar = a3;
         return a2;
     }
-    public int wideSetBar4iReturnDummyArg3(int a1, int a2, int a3, long a4) {
+    public int wideSetBar4iReturnArg3(int a1, int a2, int a3, long a4) {
         lbar = a4;
         return a3;
     }
-    public int wideSetBar5iReturnDummyArg4(int a1, int a2, int a3, int a4, long a5) {
+    public int wideSetBar5iReturnArg4(int a1, int a2, int a3, int a4, long a5) {
         lbar = a5;
         return a4;
     }
diff --git a/test/115-native-bridge/nativebridge.cc b/test/115-native-bridge/nativebridge.cc
index 754cb00..3209449 100644
--- a/test/115-native-bridge/nativebridge.cc
+++ b/test/115-native-bridge/nativebridge.cc
@@ -579,7 +579,7 @@
   return true;
 }
 
-// A dummy special handler, continueing after the faulting location. This code comes from
+// A placeholder special handler, continueing after the faulting location. This code comes from
 // 004-SignalTest.
 static bool nb_signalhandler(int sig, siginfo_t* info, void* context) {
   printf("NB signal handler with signal %d.\n", sig);
diff --git a/test/126-miranda-multidex/src/MirandaClass.java b/test/126-miranda-multidex/src/MirandaClass.java
index 7bb37e7..38e729a 100644
--- a/test/126-miranda-multidex/src/MirandaClass.java
+++ b/test/126-miranda-multidex/src/MirandaClass.java
@@ -34,19 +34,19 @@
     }
 
     // Better not hit any of these...
-    public void inInterfaceDummy1() {
-        System.out.println("inInterfaceDummy1");
+    public void inInterfaceUnused1() {
+        System.out.println("inInterfaceUnused1");
     }
-    public void inInterfaceDummy2() {
-        System.out.println("inInterfaceDummy2");
+    public void inInterfaceUnused2() {
+        System.out.println("inInterfaceUnused2");
     }
-    public void inInterfaceDummy3() {
-        System.out.println("inInterfaceDummy3");
+    public void inInterfaceUnused3() {
+        System.out.println("inInterfaceUnused3");
     }
-    public void inInterfaceDummy4() {
-        System.out.println("inInterfaceDummy4");
+    public void inInterfaceUnused4() {
+        System.out.println("inInterfaceUnused4");
     }
-    public void inInterfaceDummy5() {
-        System.out.println("inInterfaceDummy5");
+    public void inInterfaceUnused5() {
+        System.out.println("inInterfaceUnused5");
     }
 }
diff --git a/test/126-miranda-multidex/src/MirandaClass2.java b/test/126-miranda-multidex/src/MirandaClass2.java
index 797ead2..cdc1a80 100644
--- a/test/126-miranda-multidex/src/MirandaClass2.java
+++ b/test/126-miranda-multidex/src/MirandaClass2.java
@@ -24,19 +24,19 @@
     }
 
     // Better not hit any of these...
-    public void inInterfaceDummy1() {
-        System.out.println("inInterfaceDummy1");
+    public void inInterfaceUnused1() {
+        System.out.println("inInterfaceUnused1");
     }
-    public void inInterfaceDummy2() {
-        System.out.println("inInterfaceDummy2");
+    public void inInterfaceUnused2() {
+        System.out.println("inInterfaceUnused2");
     }
-    public void inInterfaceDummy3() {
-        System.out.println("inInterfaceDummy3");
+    public void inInterfaceUnused3() {
+        System.out.println("inInterfaceUnused3");
     }
-    public void inInterfaceDummy4() {
-        System.out.println("inInterfaceDummy4");
+    public void inInterfaceUnused4() {
+        System.out.println("inInterfaceUnused4");
     }
-    public void inInterfaceDummy5() {
-        System.out.println("inInterfaceDummy5");
+    public void inInterfaceUnused5() {
+        System.out.println("inInterfaceUnused5");
     }
 }
diff --git a/test/126-miranda-multidex/src/MirandaInterface.java b/test/126-miranda-multidex/src/MirandaInterface.java
index df12fcc..29b5c1d 100644
--- a/test/126-miranda-multidex/src/MirandaInterface.java
+++ b/test/126-miranda-multidex/src/MirandaInterface.java
@@ -21,11 +21,11 @@
 
     public boolean inInterface();
 
-    // A couple of dummy methods to fill the method table.
-    public void inInterfaceDummy1();
-    public void inInterfaceDummy2();
-    public void inInterfaceDummy3();
-    public void inInterfaceDummy4();
-    public void inInterfaceDummy5();
+    // Otherwise unused methods to fill the method table.
+    public void inInterfaceUnused1();
+    public void inInterfaceUnused2();
+    public void inInterfaceUnused3();
+    public void inInterfaceUnused4();
+    public void inInterfaceUnused5();
 
 }
diff --git a/test/2026-DifferentMemoryLSCouples/src/Main.java b/test/2026-DifferentMemoryLSCouples/src/Main.java
index f5a305e..8425d86 100644
--- a/test/2026-DifferentMemoryLSCouples/src/Main.java
+++ b/test/2026-DifferentMemoryLSCouples/src/Main.java
@@ -16,11 +16,11 @@
 public class Main {
     class A {
         int fieldA;
-        int dummy;
+        int placeholder;
     }
 
     class B {
-        int dummy;
+        int placeholder;
         int fieldB;
     }
     public static void assertIntEquals(int expected, int result) {
diff --git a/test/2230-profile-save-hotness/src-art/Main.java b/test/2230-profile-save-hotness/src-art/Main.java
index 97177cc..b792adf 100644
--- a/test/2230-profile-save-hotness/src-art/Main.java
+++ b/test/2230-profile-save-hotness/src-art/Main.java
@@ -71,7 +71,7 @@
   public static native boolean isAotCompiled(Class<?> cls, String methodName);
   public static native int getHotnessCounter(Class<?> cls, String methodName);
 
-  private static final String TEMP_FILE_NAME_PREFIX = "dummy";
+  private static final String TEMP_FILE_NAME_PREFIX = "temp";
   private static final String TEMP_FILE_NAME_SUFFIX = "-file";
 
   private static File createTempFile() throws Exception {
diff --git a/test/421-large-frame/src/Main.java b/test/421-large-frame/src/Main.java
index 6717ba0..5f986a5 100644
--- a/test/421-large-frame/src/Main.java
+++ b/test/421-large-frame/src/Main.java
@@ -25,515 +25,515 @@
   }
 
   public static void main(String[] args) {
-    long dummy = 0L;
+    long value = 0L;
     // Sum[i = 0..499](i) = 499 * 500 / 2 = 124750L.
-    assertEquals(124750L, $opt$LargeFrame(dummy));
+    assertEquals(124750L, $opt$LargeFrame(value));
   }
 
-  static long $opt$LargeFrame(long dummy) {
-    // The argument `dummy` is used to defeat the constant folding
+  static long $opt$LargeFrame(long value) {
+    // The argument `value` is used to defeat the constant folding
     // optimization and force the compiler to allocate these variables
     // on the stack.
-    long l0 = 0L + dummy;
-    long l1 = 1L + dummy;
-    long l2 = 2L + dummy;
-    long l3 = 3L + dummy;
-    long l4 = 4L + dummy;
-    long l5 = 5L + dummy;
-    long l6 = 6L + dummy;
-    long l7 = 7L + dummy;
-    long l8 = 8L + dummy;
-    long l9 = 9L + dummy;
-    long l10 = 10L + dummy;
-    long l11 = 11L + dummy;
-    long l12 = 12L + dummy;
-    long l13 = 13L + dummy;
-    long l14 = 14L + dummy;
-    long l15 = 15L + dummy;
-    long l16 = 16L + dummy;
-    long l17 = 17L + dummy;
-    long l18 = 18L + dummy;
-    long l19 = 19L + dummy;
-    long l20 = 20L + dummy;
-    long l21 = 21L + dummy;
-    long l22 = 22L + dummy;
-    long l23 = 23L + dummy;
-    long l24 = 24L + dummy;
-    long l25 = 25L + dummy;
-    long l26 = 26L + dummy;
-    long l27 = 27L + dummy;
-    long l28 = 28L + dummy;
-    long l29 = 29L + dummy;
-    long l30 = 30L + dummy;
-    long l31 = 31L + dummy;
-    long l32 = 32L + dummy;
-    long l33 = 33L + dummy;
-    long l34 = 34L + dummy;
-    long l35 = 35L + dummy;
-    long l36 = 36L + dummy;
-    long l37 = 37L + dummy;
-    long l38 = 38L + dummy;
-    long l39 = 39L + dummy;
-    long l40 = 40L + dummy;
-    long l41 = 41L + dummy;
-    long l42 = 42L + dummy;
-    long l43 = 43L + dummy;
-    long l44 = 44L + dummy;
-    long l45 = 45L + dummy;
-    long l46 = 46L + dummy;
-    long l47 = 47L + dummy;
-    long l48 = 48L + dummy;
-    long l49 = 49L + dummy;
-    long l50 = 50L + dummy;
-    long l51 = 51L + dummy;
-    long l52 = 52L + dummy;
-    long l53 = 53L + dummy;
-    long l54 = 54L + dummy;
-    long l55 = 55L + dummy;
-    long l56 = 56L + dummy;
-    long l57 = 57L + dummy;
-    long l58 = 58L + dummy;
-    long l59 = 59L + dummy;
-    long l60 = 60L + dummy;
-    long l61 = 61L + dummy;
-    long l62 = 62L + dummy;
-    long l63 = 63L + dummy;
-    long l64 = 64L + dummy;
-    long l65 = 65L + dummy;
-    long l66 = 66L + dummy;
-    long l67 = 67L + dummy;
-    long l68 = 68L + dummy;
-    long l69 = 69L + dummy;
-    long l70 = 70L + dummy;
-    long l71 = 71L + dummy;
-    long l72 = 72L + dummy;
-    long l73 = 73L + dummy;
-    long l74 = 74L + dummy;
-    long l75 = 75L + dummy;
-    long l76 = 76L + dummy;
-    long l77 = 77L + dummy;
-    long l78 = 78L + dummy;
-    long l79 = 79L + dummy;
-    long l80 = 80L + dummy;
-    long l81 = 81L + dummy;
-    long l82 = 82L + dummy;
-    long l83 = 83L + dummy;
-    long l84 = 84L + dummy;
-    long l85 = 85L + dummy;
-    long l86 = 86L + dummy;
-    long l87 = 87L + dummy;
-    long l88 = 88L + dummy;
-    long l89 = 89L + dummy;
-    long l90 = 90L + dummy;
-    long l91 = 91L + dummy;
-    long l92 = 92L + dummy;
-    long l93 = 93L + dummy;
-    long l94 = 94L + dummy;
-    long l95 = 95L + dummy;
-    long l96 = 96L + dummy;
-    long l97 = 97L + dummy;
-    long l98 = 98L + dummy;
-    long l99 = 99L + dummy;
-    long l100 = 100L + dummy;
-    long l101 = 101L + dummy;
-    long l102 = 102L + dummy;
-    long l103 = 103L + dummy;
-    long l104 = 104L + dummy;
-    long l105 = 105L + dummy;
-    long l106 = 106L + dummy;
-    long l107 = 107L + dummy;
-    long l108 = 108L + dummy;
-    long l109 = 109L + dummy;
-    long l110 = 110L + dummy;
-    long l111 = 111L + dummy;
-    long l112 = 112L + dummy;
-    long l113 = 113L + dummy;
-    long l114 = 114L + dummy;
-    long l115 = 115L + dummy;
-    long l116 = 116L + dummy;
-    long l117 = 117L + dummy;
-    long l118 = 118L + dummy;
-    long l119 = 119L + dummy;
-    long l120 = 120L + dummy;
-    long l121 = 121L + dummy;
-    long l122 = 122L + dummy;
-    long l123 = 123L + dummy;
-    long l124 = 124L + dummy;
-    long l125 = 125L + dummy;
-    long l126 = 126L + dummy;
-    long l127 = 127L + dummy;
-    long l128 = 128L + dummy;
-    long l129 = 129L + dummy;
-    long l130 = 130L + dummy;
-    long l131 = 131L + dummy;
-    long l132 = 132L + dummy;
-    long l133 = 133L + dummy;
-    long l134 = 134L + dummy;
-    long l135 = 135L + dummy;
-    long l136 = 136L + dummy;
-    long l137 = 137L + dummy;
-    long l138 = 138L + dummy;
-    long l139 = 139L + dummy;
-    long l140 = 140L + dummy;
-    long l141 = 141L + dummy;
-    long l142 = 142L + dummy;
-    long l143 = 143L + dummy;
-    long l144 = 144L + dummy;
-    long l145 = 145L + dummy;
-    long l146 = 146L + dummy;
-    long l147 = 147L + dummy;
-    long l148 = 148L + dummy;
-    long l149 = 149L + dummy;
-    long l150 = 150L + dummy;
-    long l151 = 151L + dummy;
-    long l152 = 152L + dummy;
-    long l153 = 153L + dummy;
-    long l154 = 154L + dummy;
-    long l155 = 155L + dummy;
-    long l156 = 156L + dummy;
-    long l157 = 157L + dummy;
-    long l158 = 158L + dummy;
-    long l159 = 159L + dummy;
-    long l160 = 160L + dummy;
-    long l161 = 161L + dummy;
-    long l162 = 162L + dummy;
-    long l163 = 163L + dummy;
-    long l164 = 164L + dummy;
-    long l165 = 165L + dummy;
-    long l166 = 166L + dummy;
-    long l167 = 167L + dummy;
-    long l168 = 168L + dummy;
-    long l169 = 169L + dummy;
-    long l170 = 170L + dummy;
-    long l171 = 171L + dummy;
-    long l172 = 172L + dummy;
-    long l173 = 173L + dummy;
-    long l174 = 174L + dummy;
-    long l175 = 175L + dummy;
-    long l176 = 176L + dummy;
-    long l177 = 177L + dummy;
-    long l178 = 178L + dummy;
-    long l179 = 179L + dummy;
-    long l180 = 180L + dummy;
-    long l181 = 181L + dummy;
-    long l182 = 182L + dummy;
-    long l183 = 183L + dummy;
-    long l184 = 184L + dummy;
-    long l185 = 185L + dummy;
-    long l186 = 186L + dummy;
-    long l187 = 187L + dummy;
-    long l188 = 188L + dummy;
-    long l189 = 189L + dummy;
-    long l190 = 190L + dummy;
-    long l191 = 191L + dummy;
-    long l192 = 192L + dummy;
-    long l193 = 193L + dummy;
-    long l194 = 194L + dummy;
-    long l195 = 195L + dummy;
-    long l196 = 196L + dummy;
-    long l197 = 197L + dummy;
-    long l198 = 198L + dummy;
-    long l199 = 199L + dummy;
-    long l200 = 200L + dummy;
-    long l201 = 201L + dummy;
-    long l202 = 202L + dummy;
-    long l203 = 203L + dummy;
-    long l204 = 204L + dummy;
-    long l205 = 205L + dummy;
-    long l206 = 206L + dummy;
-    long l207 = 207L + dummy;
-    long l208 = 208L + dummy;
-    long l209 = 209L + dummy;
-    long l210 = 210L + dummy;
-    long l211 = 211L + dummy;
-    long l212 = 212L + dummy;
-    long l213 = 213L + dummy;
-    long l214 = 214L + dummy;
-    long l215 = 215L + dummy;
-    long l216 = 216L + dummy;
-    long l217 = 217L + dummy;
-    long l218 = 218L + dummy;
-    long l219 = 219L + dummy;
-    long l220 = 220L + dummy;
-    long l221 = 221L + dummy;
-    long l222 = 222L + dummy;
-    long l223 = 223L + dummy;
-    long l224 = 224L + dummy;
-    long l225 = 225L + dummy;
-    long l226 = 226L + dummy;
-    long l227 = 227L + dummy;
-    long l228 = 228L + dummy;
-    long l229 = 229L + dummy;
-    long l230 = 230L + dummy;
-    long l231 = 231L + dummy;
-    long l232 = 232L + dummy;
-    long l233 = 233L + dummy;
-    long l234 = 234L + dummy;
-    long l235 = 235L + dummy;
-    long l236 = 236L + dummy;
-    long l237 = 237L + dummy;
-    long l238 = 238L + dummy;
-    long l239 = 239L + dummy;
-    long l240 = 240L + dummy;
-    long l241 = 241L + dummy;
-    long l242 = 242L + dummy;
-    long l243 = 243L + dummy;
-    long l244 = 244L + dummy;
-    long l245 = 245L + dummy;
-    long l246 = 246L + dummy;
-    long l247 = 247L + dummy;
-    long l248 = 248L + dummy;
-    long l249 = 249L + dummy;
-    long l250 = 250L + dummy;
-    long l251 = 251L + dummy;
-    long l252 = 252L + dummy;
-    long l253 = 253L + dummy;
-    long l254 = 254L + dummy;
-    long l255 = 255L + dummy;
-    long l256 = 256L + dummy;
-    long l257 = 257L + dummy;
-    long l258 = 258L + dummy;
-    long l259 = 259L + dummy;
-    long l260 = 260L + dummy;
-    long l261 = 261L + dummy;
-    long l262 = 262L + dummy;
-    long l263 = 263L + dummy;
-    long l264 = 264L + dummy;
-    long l265 = 265L + dummy;
-    long l266 = 266L + dummy;
-    long l267 = 267L + dummy;
-    long l268 = 268L + dummy;
-    long l269 = 269L + dummy;
-    long l270 = 270L + dummy;
-    long l271 = 271L + dummy;
-    long l272 = 272L + dummy;
-    long l273 = 273L + dummy;
-    long l274 = 274L + dummy;
-    long l275 = 275L + dummy;
-    long l276 = 276L + dummy;
-    long l277 = 277L + dummy;
-    long l278 = 278L + dummy;
-    long l279 = 279L + dummy;
-    long l280 = 280L + dummy;
-    long l281 = 281L + dummy;
-    long l282 = 282L + dummy;
-    long l283 = 283L + dummy;
-    long l284 = 284L + dummy;
-    long l285 = 285L + dummy;
-    long l286 = 286L + dummy;
-    long l287 = 287L + dummy;
-    long l288 = 288L + dummy;
-    long l289 = 289L + dummy;
-    long l290 = 290L + dummy;
-    long l291 = 291L + dummy;
-    long l292 = 292L + dummy;
-    long l293 = 293L + dummy;
-    long l294 = 294L + dummy;
-    long l295 = 295L + dummy;
-    long l296 = 296L + dummy;
-    long l297 = 297L + dummy;
-    long l298 = 298L + dummy;
-    long l299 = 299L + dummy;
-    long l300 = 300L + dummy;
-    long l301 = 301L + dummy;
-    long l302 = 302L + dummy;
-    long l303 = 303L + dummy;
-    long l304 = 304L + dummy;
-    long l305 = 305L + dummy;
-    long l306 = 306L + dummy;
-    long l307 = 307L + dummy;
-    long l308 = 308L + dummy;
-    long l309 = 309L + dummy;
-    long l310 = 310L + dummy;
-    long l311 = 311L + dummy;
-    long l312 = 312L + dummy;
-    long l313 = 313L + dummy;
-    long l314 = 314L + dummy;
-    long l315 = 315L + dummy;
-    long l316 = 316L + dummy;
-    long l317 = 317L + dummy;
-    long l318 = 318L + dummy;
-    long l319 = 319L + dummy;
-    long l320 = 320L + dummy;
-    long l321 = 321L + dummy;
-    long l322 = 322L + dummy;
-    long l323 = 323L + dummy;
-    long l324 = 324L + dummy;
-    long l325 = 325L + dummy;
-    long l326 = 326L + dummy;
-    long l327 = 327L + dummy;
-    long l328 = 328L + dummy;
-    long l329 = 329L + dummy;
-    long l330 = 330L + dummy;
-    long l331 = 331L + dummy;
-    long l332 = 332L + dummy;
-    long l333 = 333L + dummy;
-    long l334 = 334L + dummy;
-    long l335 = 335L + dummy;
-    long l336 = 336L + dummy;
-    long l337 = 337L + dummy;
-    long l338 = 338L + dummy;
-    long l339 = 339L + dummy;
-    long l340 = 340L + dummy;
-    long l341 = 341L + dummy;
-    long l342 = 342L + dummy;
-    long l343 = 343L + dummy;
-    long l344 = 344L + dummy;
-    long l345 = 345L + dummy;
-    long l346 = 346L + dummy;
-    long l347 = 347L + dummy;
-    long l348 = 348L + dummy;
-    long l349 = 349L + dummy;
-    long l350 = 350L + dummy;
-    long l351 = 351L + dummy;
-    long l352 = 352L + dummy;
-    long l353 = 353L + dummy;
-    long l354 = 354L + dummy;
-    long l355 = 355L + dummy;
-    long l356 = 356L + dummy;
-    long l357 = 357L + dummy;
-    long l358 = 358L + dummy;
-    long l359 = 359L + dummy;
-    long l360 = 360L + dummy;
-    long l361 = 361L + dummy;
-    long l362 = 362L + dummy;
-    long l363 = 363L + dummy;
-    long l364 = 364L + dummy;
-    long l365 = 365L + dummy;
-    long l366 = 366L + dummy;
-    long l367 = 367L + dummy;
-    long l368 = 368L + dummy;
-    long l369 = 369L + dummy;
-    long l370 = 370L + dummy;
-    long l371 = 371L + dummy;
-    long l372 = 372L + dummy;
-    long l373 = 373L + dummy;
-    long l374 = 374L + dummy;
-    long l375 = 375L + dummy;
-    long l376 = 376L + dummy;
-    long l377 = 377L + dummy;
-    long l378 = 378L + dummy;
-    long l379 = 379L + dummy;
-    long l380 = 380L + dummy;
-    long l381 = 381L + dummy;
-    long l382 = 382L + dummy;
-    long l383 = 383L + dummy;
-    long l384 = 384L + dummy;
-    long l385 = 385L + dummy;
-    long l386 = 386L + dummy;
-    long l387 = 387L + dummy;
-    long l388 = 388L + dummy;
-    long l389 = 389L + dummy;
-    long l390 = 390L + dummy;
-    long l391 = 391L + dummy;
-    long l392 = 392L + dummy;
-    long l393 = 393L + dummy;
-    long l394 = 394L + dummy;
-    long l395 = 395L + dummy;
-    long l396 = 396L + dummy;
-    long l397 = 397L + dummy;
-    long l398 = 398L + dummy;
-    long l399 = 399L + dummy;
-    long l400 = 400L + dummy;
-    long l401 = 401L + dummy;
-    long l402 = 402L + dummy;
-    long l403 = 403L + dummy;
-    long l404 = 404L + dummy;
-    long l405 = 405L + dummy;
-    long l406 = 406L + dummy;
-    long l407 = 407L + dummy;
-    long l408 = 408L + dummy;
-    long l409 = 409L + dummy;
-    long l410 = 410L + dummy;
-    long l411 = 411L + dummy;
-    long l412 = 412L + dummy;
-    long l413 = 413L + dummy;
-    long l414 = 414L + dummy;
-    long l415 = 415L + dummy;
-    long l416 = 416L + dummy;
-    long l417 = 417L + dummy;
-    long l418 = 418L + dummy;
-    long l419 = 419L + dummy;
-    long l420 = 420L + dummy;
-    long l421 = 421L + dummy;
-    long l422 = 422L + dummy;
-    long l423 = 423L + dummy;
-    long l424 = 424L + dummy;
-    long l425 = 425L + dummy;
-    long l426 = 426L + dummy;
-    long l427 = 427L + dummy;
-    long l428 = 428L + dummy;
-    long l429 = 429L + dummy;
-    long l430 = 430L + dummy;
-    long l431 = 431L + dummy;
-    long l432 = 432L + dummy;
-    long l433 = 433L + dummy;
-    long l434 = 434L + dummy;
-    long l435 = 435L + dummy;
-    long l436 = 436L + dummy;
-    long l437 = 437L + dummy;
-    long l438 = 438L + dummy;
-    long l439 = 439L + dummy;
-    long l440 = 440L + dummy;
-    long l441 = 441L + dummy;
-    long l442 = 442L + dummy;
-    long l443 = 443L + dummy;
-    long l444 = 444L + dummy;
-    long l445 = 445L + dummy;
-    long l446 = 446L + dummy;
-    long l447 = 447L + dummy;
-    long l448 = 448L + dummy;
-    long l449 = 449L + dummy;
-    long l450 = 450L + dummy;
-    long l451 = 451L + dummy;
-    long l452 = 452L + dummy;
-    long l453 = 453L + dummy;
-    long l454 = 454L + dummy;
-    long l455 = 455L + dummy;
-    long l456 = 456L + dummy;
-    long l457 = 457L + dummy;
-    long l458 = 458L + dummy;
-    long l459 = 459L + dummy;
-    long l460 = 460L + dummy;
-    long l461 = 461L + dummy;
-    long l462 = 462L + dummy;
-    long l463 = 463L + dummy;
-    long l464 = 464L + dummy;
-    long l465 = 465L + dummy;
-    long l466 = 466L + dummy;
-    long l467 = 467L + dummy;
-    long l468 = 468L + dummy;
-    long l469 = 469L + dummy;
-    long l470 = 470L + dummy;
-    long l471 = 471L + dummy;
-    long l472 = 472L + dummy;
-    long l473 = 473L + dummy;
-    long l474 = 474L + dummy;
-    long l475 = 475L + dummy;
-    long l476 = 476L + dummy;
-    long l477 = 477L + dummy;
-    long l478 = 478L + dummy;
-    long l479 = 479L + dummy;
-    long l480 = 480L + dummy;
-    long l481 = 481L + dummy;
-    long l482 = 482L + dummy;
-    long l483 = 483L + dummy;
-    long l484 = 484L + dummy;
-    long l485 = 485L + dummy;
-    long l486 = 486L + dummy;
-    long l487 = 487L + dummy;
-    long l488 = 488L + dummy;
-    long l489 = 489L + dummy;
-    long l490 = 490L + dummy;
-    long l491 = 491L + dummy;
-    long l492 = 492L + dummy;
-    long l493 = 493L + dummy;
-    long l494 = 494L + dummy;
-    long l495 = 495L + dummy;
-    long l496 = 496L + dummy;
-    long l497 = 497L + dummy;
-    long l498 = 498L + dummy;
-    long l499 = 499L + dummy;
+    long l0 = 0L + value;
+    long l1 = 1L + value;
+    long l2 = 2L + value;
+    long l3 = 3L + value;
+    long l4 = 4L + value;
+    long l5 = 5L + value;
+    long l6 = 6L + value;
+    long l7 = 7L + value;
+    long l8 = 8L + value;
+    long l9 = 9L + value;
+    long l10 = 10L + value;
+    long l11 = 11L + value;
+    long l12 = 12L + value;
+    long l13 = 13L + value;
+    long l14 = 14L + value;
+    long l15 = 15L + value;
+    long l16 = 16L + value;
+    long l17 = 17L + value;
+    long l18 = 18L + value;
+    long l19 = 19L + value;
+    long l20 = 20L + value;
+    long l21 = 21L + value;
+    long l22 = 22L + value;
+    long l23 = 23L + value;
+    long l24 = 24L + value;
+    long l25 = 25L + value;
+    long l26 = 26L + value;
+    long l27 = 27L + value;
+    long l28 = 28L + value;
+    long l29 = 29L + value;
+    long l30 = 30L + value;
+    long l31 = 31L + value;
+    long l32 = 32L + value;
+    long l33 = 33L + value;
+    long l34 = 34L + value;
+    long l35 = 35L + value;
+    long l36 = 36L + value;
+    long l37 = 37L + value;
+    long l38 = 38L + value;
+    long l39 = 39L + value;
+    long l40 = 40L + value;
+    long l41 = 41L + value;
+    long l42 = 42L + value;
+    long l43 = 43L + value;
+    long l44 = 44L + value;
+    long l45 = 45L + value;
+    long l46 = 46L + value;
+    long l47 = 47L + value;
+    long l48 = 48L + value;
+    long l49 = 49L + value;
+    long l50 = 50L + value;
+    long l51 = 51L + value;
+    long l52 = 52L + value;
+    long l53 = 53L + value;
+    long l54 = 54L + value;
+    long l55 = 55L + value;
+    long l56 = 56L + value;
+    long l57 = 57L + value;
+    long l58 = 58L + value;
+    long l59 = 59L + value;
+    long l60 = 60L + value;
+    long l61 = 61L + value;
+    long l62 = 62L + value;
+    long l63 = 63L + value;
+    long l64 = 64L + value;
+    long l65 = 65L + value;
+    long l66 = 66L + value;
+    long l67 = 67L + value;
+    long l68 = 68L + value;
+    long l69 = 69L + value;
+    long l70 = 70L + value;
+    long l71 = 71L + value;
+    long l72 = 72L + value;
+    long l73 = 73L + value;
+    long l74 = 74L + value;
+    long l75 = 75L + value;
+    long l76 = 76L + value;
+    long l77 = 77L + value;
+    long l78 = 78L + value;
+    long l79 = 79L + value;
+    long l80 = 80L + value;
+    long l81 = 81L + value;
+    long l82 = 82L + value;
+    long l83 = 83L + value;
+    long l84 = 84L + value;
+    long l85 = 85L + value;
+    long l86 = 86L + value;
+    long l87 = 87L + value;
+    long l88 = 88L + value;
+    long l89 = 89L + value;
+    long l90 = 90L + value;
+    long l91 = 91L + value;
+    long l92 = 92L + value;
+    long l93 = 93L + value;
+    long l94 = 94L + value;
+    long l95 = 95L + value;
+    long l96 = 96L + value;
+    long l97 = 97L + value;
+    long l98 = 98L + value;
+    long l99 = 99L + value;
+    long l100 = 100L + value;
+    long l101 = 101L + value;
+    long l102 = 102L + value;
+    long l103 = 103L + value;
+    long l104 = 104L + value;
+    long l105 = 105L + value;
+    long l106 = 106L + value;
+    long l107 = 107L + value;
+    long l108 = 108L + value;
+    long l109 = 109L + value;
+    long l110 = 110L + value;
+    long l111 = 111L + value;
+    long l112 = 112L + value;
+    long l113 = 113L + value;
+    long l114 = 114L + value;
+    long l115 = 115L + value;
+    long l116 = 116L + value;
+    long l117 = 117L + value;
+    long l118 = 118L + value;
+    long l119 = 119L + value;
+    long l120 = 120L + value;
+    long l121 = 121L + value;
+    long l122 = 122L + value;
+    long l123 = 123L + value;
+    long l124 = 124L + value;
+    long l125 = 125L + value;
+    long l126 = 126L + value;
+    long l127 = 127L + value;
+    long l128 = 128L + value;
+    long l129 = 129L + value;
+    long l130 = 130L + value;
+    long l131 = 131L + value;
+    long l132 = 132L + value;
+    long l133 = 133L + value;
+    long l134 = 134L + value;
+    long l135 = 135L + value;
+    long l136 = 136L + value;
+    long l137 = 137L + value;
+    long l138 = 138L + value;
+    long l139 = 139L + value;
+    long l140 = 140L + value;
+    long l141 = 141L + value;
+    long l142 = 142L + value;
+    long l143 = 143L + value;
+    long l144 = 144L + value;
+    long l145 = 145L + value;
+    long l146 = 146L + value;
+    long l147 = 147L + value;
+    long l148 = 148L + value;
+    long l149 = 149L + value;
+    long l150 = 150L + value;
+    long l151 = 151L + value;
+    long l152 = 152L + value;
+    long l153 = 153L + value;
+    long l154 = 154L + value;
+    long l155 = 155L + value;
+    long l156 = 156L + value;
+    long l157 = 157L + value;
+    long l158 = 158L + value;
+    long l159 = 159L + value;
+    long l160 = 160L + value;
+    long l161 = 161L + value;
+    long l162 = 162L + value;
+    long l163 = 163L + value;
+    long l164 = 164L + value;
+    long l165 = 165L + value;
+    long l166 = 166L + value;
+    long l167 = 167L + value;
+    long l168 = 168L + value;
+    long l169 = 169L + value;
+    long l170 = 170L + value;
+    long l171 = 171L + value;
+    long l172 = 172L + value;
+    long l173 = 173L + value;
+    long l174 = 174L + value;
+    long l175 = 175L + value;
+    long l176 = 176L + value;
+    long l177 = 177L + value;
+    long l178 = 178L + value;
+    long l179 = 179L + value;
+    long l180 = 180L + value;
+    long l181 = 181L + value;
+    long l182 = 182L + value;
+    long l183 = 183L + value;
+    long l184 = 184L + value;
+    long l185 = 185L + value;
+    long l186 = 186L + value;
+    long l187 = 187L + value;
+    long l188 = 188L + value;
+    long l189 = 189L + value;
+    long l190 = 190L + value;
+    long l191 = 191L + value;
+    long l192 = 192L + value;
+    long l193 = 193L + value;
+    long l194 = 194L + value;
+    long l195 = 195L + value;
+    long l196 = 196L + value;
+    long l197 = 197L + value;
+    long l198 = 198L + value;
+    long l199 = 199L + value;
+    long l200 = 200L + value;
+    long l201 = 201L + value;
+    long l202 = 202L + value;
+    long l203 = 203L + value;
+    long l204 = 204L + value;
+    long l205 = 205L + value;
+    long l206 = 206L + value;
+    long l207 = 207L + value;
+    long l208 = 208L + value;
+    long l209 = 209L + value;
+    long l210 = 210L + value;
+    long l211 = 211L + value;
+    long l212 = 212L + value;
+    long l213 = 213L + value;
+    long l214 = 214L + value;
+    long l215 = 215L + value;
+    long l216 = 216L + value;
+    long l217 = 217L + value;
+    long l218 = 218L + value;
+    long l219 = 219L + value;
+    long l220 = 220L + value;
+    long l221 = 221L + value;
+    long l222 = 222L + value;
+    long l223 = 223L + value;
+    long l224 = 224L + value;
+    long l225 = 225L + value;
+    long l226 = 226L + value;
+    long l227 = 227L + value;
+    long l228 = 228L + value;
+    long l229 = 229L + value;
+    long l230 = 230L + value;
+    long l231 = 231L + value;
+    long l232 = 232L + value;
+    long l233 = 233L + value;
+    long l234 = 234L + value;
+    long l235 = 235L + value;
+    long l236 = 236L + value;
+    long l237 = 237L + value;
+    long l238 = 238L + value;
+    long l239 = 239L + value;
+    long l240 = 240L + value;
+    long l241 = 241L + value;
+    long l242 = 242L + value;
+    long l243 = 243L + value;
+    long l244 = 244L + value;
+    long l245 = 245L + value;
+    long l246 = 246L + value;
+    long l247 = 247L + value;
+    long l248 = 248L + value;
+    long l249 = 249L + value;
+    long l250 = 250L + value;
+    long l251 = 251L + value;
+    long l252 = 252L + value;
+    long l253 = 253L + value;
+    long l254 = 254L + value;
+    long l255 = 255L + value;
+    long l256 = 256L + value;
+    long l257 = 257L + value;
+    long l258 = 258L + value;
+    long l259 = 259L + value;
+    long l260 = 260L + value;
+    long l261 = 261L + value;
+    long l262 = 262L + value;
+    long l263 = 263L + value;
+    long l264 = 264L + value;
+    long l265 = 265L + value;
+    long l266 = 266L + value;
+    long l267 = 267L + value;
+    long l268 = 268L + value;
+    long l269 = 269L + value;
+    long l270 = 270L + value;
+    long l271 = 271L + value;
+    long l272 = 272L + value;
+    long l273 = 273L + value;
+    long l274 = 274L + value;
+    long l275 = 275L + value;
+    long l276 = 276L + value;
+    long l277 = 277L + value;
+    long l278 = 278L + value;
+    long l279 = 279L + value;
+    long l280 = 280L + value;
+    long l281 = 281L + value;
+    long l282 = 282L + value;
+    long l283 = 283L + value;
+    long l284 = 284L + value;
+    long l285 = 285L + value;
+    long l286 = 286L + value;
+    long l287 = 287L + value;
+    long l288 = 288L + value;
+    long l289 = 289L + value;
+    long l290 = 290L + value;
+    long l291 = 291L + value;
+    long l292 = 292L + value;
+    long l293 = 293L + value;
+    long l294 = 294L + value;
+    long l295 = 295L + value;
+    long l296 = 296L + value;
+    long l297 = 297L + value;
+    long l298 = 298L + value;
+    long l299 = 299L + value;
+    long l300 = 300L + value;
+    long l301 = 301L + value;
+    long l302 = 302L + value;
+    long l303 = 303L + value;
+    long l304 = 304L + value;
+    long l305 = 305L + value;
+    long l306 = 306L + value;
+    long l307 = 307L + value;
+    long l308 = 308L + value;
+    long l309 = 309L + value;
+    long l310 = 310L + value;
+    long l311 = 311L + value;
+    long l312 = 312L + value;
+    long l313 = 313L + value;
+    long l314 = 314L + value;
+    long l315 = 315L + value;
+    long l316 = 316L + value;
+    long l317 = 317L + value;
+    long l318 = 318L + value;
+    long l319 = 319L + value;
+    long l320 = 320L + value;
+    long l321 = 321L + value;
+    long l322 = 322L + value;
+    long l323 = 323L + value;
+    long l324 = 324L + value;
+    long l325 = 325L + value;
+    long l326 = 326L + value;
+    long l327 = 327L + value;
+    long l328 = 328L + value;
+    long l329 = 329L + value;
+    long l330 = 330L + value;
+    long l331 = 331L + value;
+    long l332 = 332L + value;
+    long l333 = 333L + value;
+    long l334 = 334L + value;
+    long l335 = 335L + value;
+    long l336 = 336L + value;
+    long l337 = 337L + value;
+    long l338 = 338L + value;
+    long l339 = 339L + value;
+    long l340 = 340L + value;
+    long l341 = 341L + value;
+    long l342 = 342L + value;
+    long l343 = 343L + value;
+    long l344 = 344L + value;
+    long l345 = 345L + value;
+    long l346 = 346L + value;
+    long l347 = 347L + value;
+    long l348 = 348L + value;
+    long l349 = 349L + value;
+    long l350 = 350L + value;
+    long l351 = 351L + value;
+    long l352 = 352L + value;
+    long l353 = 353L + value;
+    long l354 = 354L + value;
+    long l355 = 355L + value;
+    long l356 = 356L + value;
+    long l357 = 357L + value;
+    long l358 = 358L + value;
+    long l359 = 359L + value;
+    long l360 = 360L + value;
+    long l361 = 361L + value;
+    long l362 = 362L + value;
+    long l363 = 363L + value;
+    long l364 = 364L + value;
+    long l365 = 365L + value;
+    long l366 = 366L + value;
+    long l367 = 367L + value;
+    long l368 = 368L + value;
+    long l369 = 369L + value;
+    long l370 = 370L + value;
+    long l371 = 371L + value;
+    long l372 = 372L + value;
+    long l373 = 373L + value;
+    long l374 = 374L + value;
+    long l375 = 375L + value;
+    long l376 = 376L + value;
+    long l377 = 377L + value;
+    long l378 = 378L + value;
+    long l379 = 379L + value;
+    long l380 = 380L + value;
+    long l381 = 381L + value;
+    long l382 = 382L + value;
+    long l383 = 383L + value;
+    long l384 = 384L + value;
+    long l385 = 385L + value;
+    long l386 = 386L + value;
+    long l387 = 387L + value;
+    long l388 = 388L + value;
+    long l389 = 389L + value;
+    long l390 = 390L + value;
+    long l391 = 391L + value;
+    long l392 = 392L + value;
+    long l393 = 393L + value;
+    long l394 = 394L + value;
+    long l395 = 395L + value;
+    long l396 = 396L + value;
+    long l397 = 397L + value;
+    long l398 = 398L + value;
+    long l399 = 399L + value;
+    long l400 = 400L + value;
+    long l401 = 401L + value;
+    long l402 = 402L + value;
+    long l403 = 403L + value;
+    long l404 = 404L + value;
+    long l405 = 405L + value;
+    long l406 = 406L + value;
+    long l407 = 407L + value;
+    long l408 = 408L + value;
+    long l409 = 409L + value;
+    long l410 = 410L + value;
+    long l411 = 411L + value;
+    long l412 = 412L + value;
+    long l413 = 413L + value;
+    long l414 = 414L + value;
+    long l415 = 415L + value;
+    long l416 = 416L + value;
+    long l417 = 417L + value;
+    long l418 = 418L + value;
+    long l419 = 419L + value;
+    long l420 = 420L + value;
+    long l421 = 421L + value;
+    long l422 = 422L + value;
+    long l423 = 423L + value;
+    long l424 = 424L + value;
+    long l425 = 425L + value;
+    long l426 = 426L + value;
+    long l427 = 427L + value;
+    long l428 = 428L + value;
+    long l429 = 429L + value;
+    long l430 = 430L + value;
+    long l431 = 431L + value;
+    long l432 = 432L + value;
+    long l433 = 433L + value;
+    long l434 = 434L + value;
+    long l435 = 435L + value;
+    long l436 = 436L + value;
+    long l437 = 437L + value;
+    long l438 = 438L + value;
+    long l439 = 439L + value;
+    long l440 = 440L + value;
+    long l441 = 441L + value;
+    long l442 = 442L + value;
+    long l443 = 443L + value;
+    long l444 = 444L + value;
+    long l445 = 445L + value;
+    long l446 = 446L + value;
+    long l447 = 447L + value;
+    long l448 = 448L + value;
+    long l449 = 449L + value;
+    long l450 = 450L + value;
+    long l451 = 451L + value;
+    long l452 = 452L + value;
+    long l453 = 453L + value;
+    long l454 = 454L + value;
+    long l455 = 455L + value;
+    long l456 = 456L + value;
+    long l457 = 457L + value;
+    long l458 = 458L + value;
+    long l459 = 459L + value;
+    long l460 = 460L + value;
+    long l461 = 461L + value;
+    long l462 = 462L + value;
+    long l463 = 463L + value;
+    long l464 = 464L + value;
+    long l465 = 465L + value;
+    long l466 = 466L + value;
+    long l467 = 467L + value;
+    long l468 = 468L + value;
+    long l469 = 469L + value;
+    long l470 = 470L + value;
+    long l471 = 471L + value;
+    long l472 = 472L + value;
+    long l473 = 473L + value;
+    long l474 = 474L + value;
+    long l475 = 475L + value;
+    long l476 = 476L + value;
+    long l477 = 477L + value;
+    long l478 = 478L + value;
+    long l479 = 479L + value;
+    long l480 = 480L + value;
+    long l481 = 481L + value;
+    long l482 = 482L + value;
+    long l483 = 483L + value;
+    long l484 = 484L + value;
+    long l485 = 485L + value;
+    long l486 = 486L + value;
+    long l487 = 487L + value;
+    long l488 = 488L + value;
+    long l489 = 489L + value;
+    long l490 = 490L + value;
+    long l491 = 491L + value;
+    long l492 = 492L + value;
+    long l493 = 493L + value;
+    long l494 = 494L + value;
+    long l495 = 495L + value;
+    long l496 = 496L + value;
+    long l497 = 497L + value;
+    long l498 = 498L + value;
+    long l499 = 499L + value;
     l1 += l0;
     l2 += l1;
     l3 += l2;
diff --git a/test/444-checker-nce/src/Main.java b/test/444-checker-nce/src/Main.java
index ddc2f77..1a8360e 100644
--- a/test/444-checker-nce/src/Main.java
+++ b/test/444-checker-nce/src/Main.java
@@ -227,7 +227,7 @@
   }
 
   public Main() {}
-  public Main(int dummy) {}
+  public Main(int unused) {}
 
   private Main g() {
     // avoids inlining
diff --git a/test/445-checker-licm/src/Main.java b/test/445-checker-licm/src/Main.java
index 5f2c4ea..a1db185 100644
--- a/test/445-checker-licm/src/Main.java
+++ b/test/445-checker-licm/src/Main.java
@@ -15,7 +15,7 @@
  */
 
 public class Main {
-  static class Dummy {
+  static class ValueHolder {
     static int getValue() {
       return 1;
     }
@@ -128,7 +128,7 @@
     int i = 0;
     int sum = 0;
     do {
-      sum += Dummy.getValue();
+      sum += ValueHolder.getValue();
       i++;
     } while (i < 10);
     return sum;
diff --git a/test/569-checker-pattern-replacement/src-multidex/Base.java b/test/569-checker-pattern-replacement/src-multidex/Base.java
index f4d59af..62322e7 100644
--- a/test/569-checker-pattern-replacement/src-multidex/Base.java
+++ b/test/569-checker-pattern-replacement/src-multidex/Base.java
@@ -59,7 +59,7 @@
     this(0.0, objectValue);
   }
 
-  Base(int intValue, long dummy) {
+  Base(int intValue, long unused) {
     this(intValue, 0.0, null);
   }
 
diff --git a/test/569-checker-pattern-replacement/src-multidex/DerivedInSecondDex.java b/test/569-checker-pattern-replacement/src-multidex/DerivedInSecondDex.java
index 50266e8..05d63c2 100644
--- a/test/569-checker-pattern-replacement/src-multidex/DerivedInSecondDex.java
+++ b/test/569-checker-pattern-replacement/src-multidex/DerivedInSecondDex.java
@@ -24,7 +24,7 @@
     super(intValue);
   }
 
-  DerivedInSecondDex(long dummy) {
+  DerivedInSecondDex(long unused) {
     // Matched: Superclass in a different dex file has an IPUT that's pruned because we store 0.
     super(0);
   }
diff --git a/test/569-checker-pattern-replacement/src-multidex/Second.java b/test/569-checker-pattern-replacement/src-multidex/Second.java
index cba1dc8..7a209de 100644
--- a/test/569-checker-pattern-replacement/src-multidex/Second.java
+++ b/test/569-checker-pattern-replacement/src-multidex/Second.java
@@ -95,7 +95,7 @@
   public int instanceIntField = 42;
   public double instanceDoubleField = -42.0;
   public Object instanceObjectField = null;
-  public String instanceStringField = "dummy";
+  public String instanceStringField = "placeholder";
   public long instanceLongField = 0;  // Overwritten by setters.
 
   public static int staticIntField = 4242;
diff --git a/test/569-checker-pattern-replacement/src/Main.java b/test/569-checker-pattern-replacement/src/Main.java
index ce7cdb0..bcf8cdd 100644
--- a/test/569-checker-pattern-replacement/src/Main.java
+++ b/test/569-checker-pattern-replacement/src/Main.java
@@ -627,8 +627,8 @@
   /// CHECK-DAG:                      InstanceFieldSet
   /// CHECK-NOT:                      InstanceFieldSet
 
-  public static double constructBase(int intValue, long dummy) {
-    Base b = new Base(intValue, dummy);
+  public static double constructBase(int intValue, long placeholder) {
+    Base b = new Base(intValue, placeholder);
     return b.intField + b.doubleField;
   }
 
@@ -1145,8 +1145,8 @@
   /// CHECK-NOT:                      ConstructorFence
   /// CHECK-NOT:                      InstanceFieldSet
 
-  public static int constructDerivedInSecondDex(long dummy) {
-    DerivedInSecondDex d = new DerivedInSecondDex(dummy);
+  public static int constructDerivedInSecondDex(long placeholder) {
+    DerivedInSecondDex d = new DerivedInSecondDex(placeholder);
     return d.intField;
   }
 
@@ -1168,7 +1168,7 @@
     assertEquals(42, getInt(s));
     assertEquals(-42.0, getDouble(s));
     assertEquals(null, getObject(s));
-    assertEquals("dummy", getString(s));
+    assertEquals("placeholder", getString(s));
     // Not replaced IGET pattern.
     assertEquals(42, staticGetInt(s));
     assertEquals(-42.0, getDoubleFromParam(s));
@@ -1198,9 +1198,9 @@
     assertEquals(-34.0, constructBase(19, 15.0, null));
     assertEquals(-22.5, constructBaseWith0DoubleNull(22.5));
     assertEquals(-8.0, constructBase(2, 14.0, null, null));
-    assertEquals(-64.0, constructBase(4, 28.0, null, "dummy"));
+    assertEquals(-64.0, constructBase(4, 28.0, null, "placeholder"));
     assertEquals(13.0, constructBase(24, 2.0, new Object(), null));
-    assertEquals(30.0, constructBase(11, 4.0, new Object(), "dummy"));
+    assertEquals(30.0, constructBase(11, 4.0, new Object(), "placeholder"));
     assertEquals(43.0, constructBase(43.0));
     assertEquals(0.0, constructBaseWith0d());
     assertEquals(1.0, constructBase(new Object()));
@@ -1216,9 +1216,9 @@
     assertEquals(-7.0, constructDerived(5, 7.0, new Object()));
     assertEquals(-4.0, constructDerived(9, 4.0, null));
     assertEquals(0.0, constructDerived(1, 9.0, null, null));
-    assertEquals(0.0, constructDerived(2, 8.0, null, "dummy"));
+    assertEquals(0.0, constructDerived(2, 8.0, null, "placeholder"));
     assertEquals(0.0, constructDerived(3, 7.0, new Object(), null));
-    assertEquals(0.0, constructDerived(4, 6.0, new Object(), "dummy"));
+    assertEquals(0.0, constructDerived(4, 6.0, new Object(), "placeholder"));
     assertEquals(17.0, constructDerived(17.0f));
     assertEquals(-5.5, constructDerived(6, -7.0, new Object(), 6.5f));
 
diff --git a/test/595-profile-saving/src/Main.java b/test/595-profile-saving/src/Main.java
index e0952e1..d9d4981 100644
--- a/test/595-profile-saving/src/Main.java
+++ b/test/595-profile-saving/src/Main.java
@@ -70,7 +70,7 @@
   // Returns true if the profile is for the boot image.
   public static native boolean isForBootImage(String profile);
 
-  private static final String TEMP_FILE_NAME_PREFIX = "dummy";
+  private static final String TEMP_FILE_NAME_PREFIX = "temp";
   private static final String TEMP_FILE_NAME_SUFFIX = "-file";
 
   static native String getProfileInfoDump(
diff --git a/test/602-deoptimizeable/src/Main.java b/test/602-deoptimizeable/src/Main.java
index 46584b0..ba75f5a 100644
--- a/test/602-deoptimizeable/src/Main.java
+++ b/test/602-deoptimizeable/src/Main.java
@@ -19,16 +19,16 @@
 import java.util.Comparator;
 import java.util.HashMap;
 
-class DummyObject {
+class TestObject {
     public static boolean sHashCodeInvoked = false;
     private int i;
 
-    public DummyObject(int i) {
+    public TestObject(int i) {
         this.i = i;
     }
 
     public boolean equals(Object obj) {
-        return (obj instanceof DummyObject) && (i == ((DummyObject)obj).i);
+        return (obj instanceof TestObject) && (i == ((TestObject)obj).i);
     }
 
     public int hashCode() {
@@ -52,7 +52,7 @@
 
     public static void main(String[] args) throws Exception {
         System.loadLibrary(args[0]);
-        final HashMap<DummyObject, Long> map = new HashMap<DummyObject, Long>();
+        final HashMap<TestObject, Long> map = new HashMap<TestObject, Long>();
 
         // Single-frame deoptimization that covers partial fragment.
         execute(new Runnable() {
@@ -103,9 +103,9 @@
         execute(new Runnable() {
             public void run() {
                 try {
-                    map.put(new DummyObject(10), Long.valueOf(100));
-                    if (map.get(new DummyObject(10)) == null) {
-                        System.out.println("Expected map to contain DummyObject(10)");
+                    map.put(new TestObject(10), Long.valueOf(100));
+                    if (map.get(new TestObject(10)) == null) {
+                        System.out.println("Expected map to contain TestObject(10)");
                     }
                 } catch (Exception e) {
                     e.printStackTrace(System.out);
@@ -115,10 +115,10 @@
 
         undeoptimizeAll();  // Make compiled code useable again.
 
-        if (!DummyObject.sHashCodeInvoked) {
+        if (!TestObject.sHashCodeInvoked) {
             System.out.println("hashCode() method not invoked!");
         }
-        if (map.get(new DummyObject(10)) != 100) {
+        if (map.get(new TestObject(10)) != 100) {
             System.out.println("Wrong hashmap value!");
         }
         System.out.println("Finishing");
diff --git a/test/622-simplifyifs-exception-edges/src/Main.java b/test/622-simplifyifs-exception-edges/src/Main.java
index 636f047..80faa4a 100644
--- a/test/622-simplifyifs-exception-edges/src/Main.java
+++ b/test/622-simplifyifs-exception-edges/src/Main.java
@@ -39,5 +39,5 @@
     }
 
     // Workaround for non-zero field ids offset in dex file with no fields. Bug: 18051191
-    static final boolean dummy = false;
+    static final boolean PLACEHOLDER = false;
 }
diff --git a/test/656-annotation-lookup-generic-jni/src-art/Main.java b/test/656-annotation-lookup-generic-jni/src-art/Main.java
index 01b288a..ed37506 100644
--- a/test/656-annotation-lookup-generic-jni/src-art/Main.java
+++ b/test/656-annotation-lookup-generic-jni/src-art/Main.java
@@ -48,7 +48,7 @@
     Method nativeMethodWithAnnotation = testClass.getMethod("nativeMethodWithAnnotation");
     // Invoking the native method Test.nativeMethodWithAnnotation used
     // to crash the Generic JNI trampoline during the resolution of
-    // the method's annotations (DummyAnnotation) (see b/38454151).
+    // the method's annotations (SampleAnnotation) (see b/38454151).
     nativeMethodWithAnnotation.invoke(null);
 
     zipFile.close();
diff --git a/test/656-annotation-lookup-generic-jni/src-ex/DummyAnnotation.java b/test/656-annotation-lookup-generic-jni/src-ex/SampleAnnotation.java
similarity index 94%
rename from test/656-annotation-lookup-generic-jni/src-ex/DummyAnnotation.java
rename to test/656-annotation-lookup-generic-jni/src-ex/SampleAnnotation.java
index 6caac66..775dd9c 100644
--- a/test/656-annotation-lookup-generic-jni/src-ex/DummyAnnotation.java
+++ b/test/656-annotation-lookup-generic-jni/src-ex/SampleAnnotation.java
@@ -14,4 +14,4 @@
  * limitations under the License.
  */
 
-public @interface DummyAnnotation {}
+public @interface SampleAnnotation {}
diff --git a/test/656-annotation-lookup-generic-jni/src-ex/Test.java b/test/656-annotation-lookup-generic-jni/src-ex/Test.java
index 838b4fe..359a9df 100644
--- a/test/656-annotation-lookup-generic-jni/src-ex/Test.java
+++ b/test/656-annotation-lookup-generic-jni/src-ex/Test.java
@@ -22,7 +22,7 @@
     System.loadLibrary(libname);
   }
 
-  @DummyAnnotation
+  @SampleAnnotation
   public static native void nativeMethodWithAnnotation();
 
 }
diff --git a/test/656-annotation-lookup-generic-jni/test.cc b/test/656-annotation-lookup-generic-jni/test.cc
index c8aa2af..172e046 100644
--- a/test/656-annotation-lookup-generic-jni/test.cc
+++ b/test/656-annotation-lookup-generic-jni/test.cc
@@ -20,7 +20,7 @@
 
 namespace art {
 
-// Native method annotated with `DummyAnnotation` in Java source.
+// Native method annotated with `SampleAnnotation` in Java source.
 extern "C" JNIEXPORT void JNICALL Java_Test_nativeMethodWithAnnotation(JNIEnv*, jclass) {
   std::cout << "Java_Test_nativeMethodWithAnnotation" << std::endl;
 }
diff --git a/test/674-hiddenapi/src-ex/Linking.java b/test/674-hiddenapi/src-ex/Linking.java
index 5aa3663..06f035f 100644
--- a/test/674-hiddenapi/src-ex/Linking.java
+++ b/test/674-hiddenapi/src-ex/Linking.java
@@ -210,31 +210,31 @@
 
 class LinkMethodInterfaceWhitelist {
   public static int access() {
-    return DummyClass.getInterfaceInstance().methodPublicWhitelist();
+    return SampleClass.getInterfaceInstance().methodPublicWhitelist();
   }
 }
 
 class LinkMethodInterfaceLightGreylist {
   public static int access() {
-    return DummyClass.getInterfaceInstance().methodPublicLightGreylist();
+    return SampleClass.getInterfaceInstance().methodPublicLightGreylist();
   }
 }
 
 class LinkMethodInterfaceDarkGreylist {
   public static int access() {
-    return DummyClass.getInterfaceInstance().methodPublicDarkGreylist();
+    return SampleClass.getInterfaceInstance().methodPublicDarkGreylist();
   }
 }
 
 class LinkMethodInterfaceBlacklist {
   public static int access() {
-    return DummyClass.getInterfaceInstance().methodPublicBlacklist();
+    return SampleClass.getInterfaceInstance().methodPublicBlacklist();
   }
 }
 
 class LinkMethodInterfaceBlacklistAndCorePlatformApi {
   public static int access() {
-    return DummyClass.getInterfaceInstance().methodPublicBlacklistAndCorePlatformApi();
+    return SampleClass.getInterfaceInstance().methodPublicBlacklistAndCorePlatformApi();
   }
 }
 
diff --git a/test/674-hiddenapi/src/DummyClass.java b/test/674-hiddenapi/src/SampleClass.java
similarity index 91%
rename from test/674-hiddenapi/src/DummyClass.java
rename to test/674-hiddenapi/src/SampleClass.java
index afba747..b2dcd1f 100644
--- a/test/674-hiddenapi/src/DummyClass.java
+++ b/test/674-hiddenapi/src/SampleClass.java
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-public class DummyClass implements ParentInterface {
+public class SampleClass implements ParentInterface {
   public int methodPublicWhitelist() { return 1; }
   public int methodPublicLightGreylist() { return 2; }
   public int methodPublicDarkGreylist() { return 3; }
@@ -22,6 +22,6 @@
   public int methodPublicBlacklistAndCorePlatformApi() { return 5; }
 
   public static ParentInterface getInterfaceInstance() {
-    return new DummyClass();
+    return new SampleClass();
   }
 }
diff --git a/test/683-clinit-inline-static-invoke/src/Main.java b/test/683-clinit-inline-static-invoke/src/Main.java
index b4ccfaa..ceccffb 100644
--- a/test/683-clinit-inline-static-invoke/src/Main.java
+++ b/test/683-clinit-inline-static-invoke/src/Main.java
@@ -26,6 +26,6 @@
     // TypeId in the current DexFile, we erroneously provided the type index from the
     // declaring DexFile and that caused a crash. This was fixed by changing the
     // ClinitCheck entrypoint to take the Class reference from LoadClass.
-    int dummy = MyTimeZone.getDefaultTimeZoneType();
+    int placeholder = MyTimeZone.getDefaultTimeZoneType();
   }
 }
diff --git a/test/685-deoptimizeable/src/Main.java b/test/685-deoptimizeable/src/Main.java
index fc7fdea..41dcfd1 100644
--- a/test/685-deoptimizeable/src/Main.java
+++ b/test/685-deoptimizeable/src/Main.java
@@ -19,16 +19,16 @@
 import java.util.Comparator;
 import java.util.HashMap;
 
-class DummyObject {
+class SampleObject {
     public static boolean sHashCodeInvoked = false;
     private int i;
 
-    public DummyObject(int i) {
+    public SampleObject(int i) {
         this.i = i;
     }
 
     public boolean equals(Object obj) {
-        return (obj instanceof DummyObject) && (i == ((DummyObject)obj).i);
+        return (obj instanceof SampleObject) && (i == ((SampleObject)obj).i);
     }
 
     public int hashCode() {
@@ -64,7 +64,7 @@
         ensureJitCompiled(Main.class, "$noinline$run2");
         ensureJitCompiled(Main.class, "$noinline$run3A");
         ensureJitCompiled(Main.class, "$noinline$run3B");
-        ensureJitCompiled(DummyObject.class, "hashCode");
+        ensureJitCompiled(SampleObject.class, "hashCode");
     }
 
     public static void main(String[] args) throws Exception {
@@ -76,7 +76,7 @@
 
         ensureAllJitCompiled();
 
-        final HashMap<DummyObject, Long> map = new HashMap<DummyObject, Long>();
+        final HashMap<SampleObject, Long> map = new HashMap<SampleObject, Long>();
 
         // Single-frame deoptimization that covers partial fragment.
         execute(new Runnable() {
@@ -156,7 +156,7 @@
             public void runInternal() {
                 try {
                     assertIsManaged();
-                    map.put(new DummyObject(10), Long.valueOf(100));
+                    map.put(new SampleObject(10), Long.valueOf(100));
                     assertIsInterpreted();  // Every deoptimizeable method is deoptimized.
                 } catch (Exception e) {
                     e.printStackTrace(System.out);
@@ -167,10 +167,10 @@
         undeoptimizeAll();  // Make compiled code useable again.
         ensureAllJitCompiled();
 
-        if (!DummyObject.sHashCodeInvoked) {
+        if (!SampleObject.sHashCodeInvoked) {
             System.out.println("hashCode() method not invoked!");
         }
-        if (map.get(new DummyObject(10)) != 100) {
+        if (map.get(new SampleObject(10)) != 100) {
             System.out.println("Wrong hashmap value!");
         }
         System.out.println("Finishing");
diff --git a/test/692-vdex-inmem-loader/src-ex/DummyClass.java b/test/692-vdex-inmem-loader/src-ex/EmptyClass.java
similarity index 95%
rename from test/692-vdex-inmem-loader/src-ex/DummyClass.java
rename to test/692-vdex-inmem-loader/src-ex/EmptyClass.java
index 443d1fe..92d8000 100644
--- a/test/692-vdex-inmem-loader/src-ex/DummyClass.java
+++ b/test/692-vdex-inmem-loader/src-ex/EmptyClass.java
@@ -14,5 +14,5 @@
  * limitations under the License.
  */
 
-public class DummyClass {
+public class EmptyClass {
 }
diff --git a/test/721-osr/src/Main.java b/test/721-osr/src/Main.java
index 2f0892c..0d41d29 100644
--- a/test/721-osr/src/Main.java
+++ b/test/721-osr/src/Main.java
@@ -33,9 +33,9 @@
         }
 
         // Loop enough to potentially trigger OSR.
-        List<Integer> dummyObjects = new ArrayList<Integer>(200_000);
+        List<Integer> placeholderObjects = new ArrayList<Integer>(200_000);
         for (int i = 0; i < 200_000; i++) {
-            dummyObjects.add(1024);
+            placeholderObjects.add(1024);
         }
 
         if (testFloat != 1000.0f) {
diff --git a/test/800-smali/smali/b_20843113.smali b/test/800-smali/smali/b_20843113.smali
index ab3dc41..0105c20 100644
--- a/test/800-smali/smali/b_20843113.smali
+++ b/test/800-smali/smali/b_20843113.smali
@@ -27,7 +27,7 @@
 .catchall {:Label1 .. :Label2} :Handler
 .end method
 
-# Just a dummy.
+# Just a placeholder.
 .method public static run()V
 .registers 1
        return-void
diff --git a/test/800-smali/smali/b_22411633_2.smali b/test/800-smali/smali/b_22411633_2.smali
index 9f27c4c..6c4be40 100644
--- a/test/800-smali/smali/b_22411633_2.smali
+++ b/test/800-smali/smali/b_22411633_2.smali
@@ -28,7 +28,7 @@
 
 :LabelMergeObject
 
-       # Dummy work to separate blocks. At this point, v4 is of type Reference<Object>.
+       # Arbitrary work to separate blocks. At this point, v4 is of type Reference<Object>.
        add-int/lit16 v3, v3, 1
 
 :LabelMerge
diff --git a/test/912-classes/src-art/art/Test912.java b/test/912-classes/src-art/art/Test912.java
index a2e8934..8e6b75f 100644
--- a/test/912-classes/src-art/art/Test912.java
+++ b/test/912-classes/src-art/art/Test912.java
@@ -64,7 +64,7 @@
     testClassStatus(Object.class);
     testClassStatus(TestForNonInit.class);
     try {
-      System.out.println(TestForInitFail.dummy);
+      System.out.println(TestForInitFail.intValue);
     } catch (ExceptionInInitializerError e) {
     }
     testClassStatus(TestForInitFail.class);
@@ -281,9 +281,9 @@
       }
     };
 
-    Thread dummyThread = new Thread();
-    dummyThread.start();
-    dummyThread.join();
+    Thread noopThread = new Thread();
+    noopThread.start();
+    noopThread.join();
 
     enableClassLoadPreparePrintEvents(true, Thread.currentThread());
 
@@ -424,12 +424,12 @@
   }
 
   private static class TestForNonInit {
-    public static double dummy = Math.random();  // So it can't be compile-time initialized.
+    public static double doubleValue = Math.random();  // So it can't be compile-time initialized.
   }
 
   @SuppressWarnings("RandomCast")
   private static class TestForInitFail {
-    public static int dummy = ((int)Math.random())/0;  // So it throws when initializing.
+    public static int intValue = ((int)Math.random())/0;  // So it throws when initializing.
   }
 
   public static interface InfA {
diff --git a/test/923-monitors/monitors.cc b/test/923-monitors/monitors.cc
index 9afe22d..e4f3860 100644
--- a/test/923-monitors/monitors.cc
+++ b/test/923-monitors/monitors.cc
@@ -40,7 +40,7 @@
 extern "C" JNIEXPORT jlong JNICALL Java_art_Test923_createRawMonitor(
     JNIEnv* env, jclass Main_klass ATTRIBUTE_UNUSED) {
   jrawMonitorID id;
-  jvmtiError result = jvmti_env->CreateRawMonitor("dummy", &id);
+  jvmtiError result = jvmti_env->CreateRawMonitor("placeholder", &id);
   if (JvmtiErrorToException(env, jvmti_env, result)) {
     return 0;
   }
diff --git a/test/956-methodhandles/src/Main.java b/test/956-methodhandles/src/Main.java
index e70c83b..5dace08 100644
--- a/test/956-methodhandles/src/Main.java
+++ b/test/956-methodhandles/src/Main.java
@@ -1172,13 +1172,13 @@
 
     // boolean -> int
     try {
-        int dummy = (int) mh.invoke("True");
+        int unexpectedValue = (int) mh.invoke("True");
         fail();
     } catch (WrongMethodTypeException e) {}
 
     // boolean -> Integer
     try {
-        Integer dummy = (Integer) mh.invoke("True");
+        Integer unexpectedValue = (Integer) mh.invoke("True");
         fail();
     } catch (WrongMethodTypeException e) {}
 
@@ -1190,13 +1190,13 @@
 
     // Boolean -> int
     try {
-        int dummy = (int) mh.invoke(false);
+        int unexpectedValue = (int) mh.invoke(false);
         fail();
     } catch (WrongMethodTypeException e) {}
 
     // Boolean -> Integer
     try {
-        Integer dummy = (Integer) mh.invoke("True");
+        Integer unexpectedValue = (Integer) mh.invoke("True");
         fail();
     } catch (WrongMethodTypeException e) {}
 
diff --git a/test/616-cha-abstract/src/Main.java b/test/616-cha-abstract/src/Main.java
index b33f575..c8093e6 100644
--- a/test/616-cha-abstract/src/Main.java
+++ b/test/616-cha-abstract/src/Main.java
@@ -55,7 +55,7 @@
 
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
   // After Dummy.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
     if (setHasJIT) {
@@ -76,7 +76,7 @@
       while (!sOtherThreadStarted);
       // Create an Main2 instance and assign it to sMain2.
       // sMain1 is kept the same.
-      sMain2 = Dummy.createMain2();
+      sMain2 = Helper.createMain2();
       // Wake up the other thread.
       synchronized(Main.class) {
         Main.class.notify();
@@ -94,7 +94,7 @@
     }
 
     // There should be a deoptimization here right after Main2 is linked by
     // calling Dummy.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -152,7 +152,7 @@
 }
 
 // Put createMain2() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Main1 createMain2() {
     return new Main2();
   }
@@ -55,7 +55,7 @@
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
-  // After Dummy.createMain2() which links in Main2, live testOverride() on stack
+  // After Helper.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
@@ -94,7 +94,7 @@
 
     // There should be a deoptimization here right after Main2 is linked by
-    // calling Dummy.createMain2(), even though sMain1 didn't change.
+    // calling Helper.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/616-cha-interface-default/src/Main.java b/test/616-cha-interface-default/src/Main.java
index 951607d..ce02cf0 100644
--- a/test/616-cha-interface-default/src/Main.java
+++ b/test/616-cha-interface-default/src/Main.java
@@ -55,7 +55,7 @@
 
   // sMain1.foo()/sMain2.foo() will be always be Base.foo() before Main3 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Base.foo() and be inlined.
   // After Dummy.createMain3() which links in Main3, live testImplement() on stack
   // should be deoptimized.
   static void testImplement(boolean createMain3, boolean wait, boolean setHasJIT) {
     if (setHasJIT) {
@@ -84,7 +84,7 @@
       while (!sOtherThreadStarted);
       // Create an Main2 instance and assign it to sMain2.
       // sMain1 is kept the same.
-      sMain3 = Dummy.createMain3();
+      sMain3 = Helper.createMain3();
       // Wake up the other thread.
       synchronized(Main.class) {
         Main.class.notify();
@@ -102,7 +102,7 @@
     }
 
     // There should be a deoptimization here right after Main3 is linked by
     // calling Dummy.createMain3(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     if (sMain1.foo(getValue(sMain1.getClass())) != 11) {
@@ -169,7 +169,7 @@
 }
 
 // Put createMain3() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Base createMain3() {
     return new Main3();
   }
@@ -55,7 +55,7 @@
   // sMain1.foo()/sMain2.foo() will be always be Base.foo() before Main3 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Base.foo() and be inlined.
-  // After Dummy.createMain3() which links in Main3, live testImplement() on stack
+  // After Helper.createMain3() which links in Main3, live testImplement() on stack
   // should be deoptimized.
   static void testImplement(boolean createMain3, boolean wait, boolean setHasJIT) {
@@ -102,7 +102,7 @@
 
     // There should be a deoptimization here right after Main3 is linked by
-    // calling Dummy.createMain3(), even though sMain1 didn't change.
+    // calling Helper.createMain3(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/616-cha-interface/src/Main.java b/test/616-cha-interface/src/Main.java
index 3c93496..c55ed6e 100644
--- a/test/616-cha-interface/src/Main.java
+++ b/test/616-cha-interface/src/Main.java
@@ -68,7 +68,7 @@
 
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
   // After Dummy.createMain2() which links in Main2, live testImplement() on stack
   // should be deoptimized.
   static void testImplement(boolean createMain2, boolean wait, boolean setHasJIT) {
     if (setHasJIT) {
@@ -90,7 +90,7 @@
       while (!sOtherThreadStarted);
       // Create an Main2 instance and assign it to sMain2.
       // sMain1 is kept the same.
-      sMain2 = Dummy.createMain2();
+      sMain2 = Helper.createMain2();
       // Wake up the other thread.
       synchronized(Main.class) {
         Main.class.notify();
@@ -108,7 +108,7 @@
     }
 
     // There should be a deoptimization here right after Main2 is linked by
     // calling Dummy.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -166,7 +166,7 @@
 }
 
 // Put createMain2() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Main1 createMain2() {
     return new Main2();
   }
@@ -68,7 +68,7 @@
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
-  // After Dummy.createMain2() which links in Main2, live testImplement() on stack
+  // After Helper.createMain2() which links in Main2, live testImplement() on stack
   // should be deoptimized.
   static void testImplement(boolean createMain2, boolean wait, boolean setHasJIT) {
@@ -108,7 +108,7 @@
 
     // There should be a deoptimization here right after Main2 is linked by
-    // calling Dummy.createMain2(), even though sMain1 didn't change.
+    // calling Helper.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/616-cha-miranda/src/Main.java b/test/616-cha-miranda/src/Main.java
index e548482..323e92e 100644
--- a/test/616-cha-miranda/src/Main.java
+++ b/test/616-cha-miranda/src/Main.java
@@ -59,7 +59,7 @@
 
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
   // After Dummy.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
     if (setHasJIT) {
@@ -80,7 +80,7 @@
       while (!sOtherThreadStarted);
       // Create an Main2 instance and assign it to sMain2.
       // sMain1 is kept the same.
-      sMain2 = Dummy.createMain2();
+      sMain2 = Helper.createMain2();
       // Wake up the other thread.
       synchronized(Main.class) {
         Main.class.notify();
@@ -98,7 +98,7 @@
     }
 
     // There should be a deoptimization here right after Main2 is linked by
     // calling Dummy.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -156,7 +156,7 @@
 }
 
 // Put createMain2() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Main1 createMain2() {
     return new Main2();
   }
@@ -59,7 +59,7 @@
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
-  // After Dummy.createMain2() which links in Main2, live testOverride() on stack
+  // After Helper.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
@@ -98,7 +98,7 @@
 
     // There should be a deoptimization here right after Main2 is linked by
-    // calling Dummy.createMain2(), even though sMain1 didn't change.
+    // calling Helper.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/616-cha-regression-proxy-method/src/Main.java b/test/616-cha-regression-proxy-method/src/Main.java
index 19c92be..176f80b 100644
--- a/test/616-cha-regression-proxy-method/src/Main.java
+++ b/test/616-cha-regression-proxy-method/src/Main.java
@@ -70,7 +70,7 @@
 
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
   // After Dummy.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride() {
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -79,14 +79,14 @@
     while (!sOtherThreadStarted);
     // Create an Main2 instance and assign it to sMain2.
     // sMain1 is kept the same.
-    sMain2 = Dummy.createMain2();
+    sMain2 = Helper.createMain2();
     // Wake up the other thread.
     synchronized(Main.class) {
       Main.class.notify();
     }
 
     // There should be a deoptimization here right after Main2 is linked by
     // calling Dummy.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -124,7 +124,7 @@
 }
 
 // Put createMain2() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Main1 createMain2() {
     return new Main2();
   }
@@ -70,7 +70,7 @@
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
-  // After Dummy.createMain2() which links in Main2, live testOverride() on stack
+  // After Helper.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride() {
@@ -79,14 +79,14 @@
 
     // There should be a deoptimization here right after Main2 is linked by
-    // calling Dummy.createMain2(), even though sMain1 didn't change.
+    // calling Helper.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/616-cha/src/Main.java b/test/616-cha/src/Main.java
index 27da7cc..39f47fa 100644
--- a/test/616-cha/src/Main.java
+++ b/test/616-cha/src/Main.java
@@ -77,7 +77,7 @@
 
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
   // After Dummy.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
     if (setHasJIT) {
@@ -98,7 +98,7 @@
       while (!sOtherThreadStarted);
       // Create an Main2 instance and assign it to sMain2.
       // sMain1 is kept the same.
-      sMain2 = Dummy.createMain2();
+      sMain2 = Helper.createMain2();
       // Wake up the other thread.
       synchronized(Main.class) {
         Main.class.notify();
@@ -116,7 +116,7 @@
     }
 
     // There should be a deoptimization here right after Main2 is linked by
     // calling Dummy.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
     sMain1.foo(sMain1.getClass() == Main1.class ? 1 : 2);
@@ -154,8 +154,8 @@
   static void testNoOverride() {
     sArray = new Main1[3];
     sArray[0] = new Main1();
-    sArray[1] = Dummy.createMain2();
-    sArray[2] = Dummy.createMain3();
+    sArray[1] = Helper.createMain2();
+    sArray[2] = Helper.createMain3();
     long sum = 0;
     // Loop enough to get methods JITed.
     for (int i=0; i<100; i++) {
@@ -243,7 +243,7 @@
 }
 
 // Put createMain2() in another class to avoid class loading due to verifier.
-class Dummy {
+class Helper {
   static Main1 createMain2() {
     return new Main2();
   }
@@ -77,7 +77,7 @@
   // sMain1.foo() will be always be Main1.foo() before Main2 is loaded/linked.
   // So sMain1.foo() can be devirtualized to Main1.foo() and be inlined.
-  // After Dummy.createMain2() which links in Main2, live testOverride() on stack
+  // After Helper.createMain2() which links in Main2, live testOverride() on stack
   // should be deoptimized.
   static void testOverride(boolean createMain2, boolean wait, boolean setHasJIT) {
@@ -116,7 +116,7 @@
 
     // There should be a deoptimization here right after Main2 is linked by
-    // calling Dummy.createMain2(), even though sMain1 didn't change.
+    // calling Helper.createMain2(), even though sMain1 didn't change.
     // The behavior here would be different if inline-cache is used, which
     // doesn't deoptimize since sMain1 still hits the type cache.
diff --git a/test/910-methods/src/art/Test910.java b/test/910-methods/src/art/Test910.java
index e1da277..4338448 100644
--- a/test/910-methods/src/art/Test910.java
+++ b/test/910-methods/src/art/Test910.java
@@ -33,7 +33,7 @@
 
     testMethod(getProxyClass(), "run");
 
     // Find a synthetic method in the dummy inner class. Do not print the name. Javac and Jack
     // disagree on the naming of synthetic accessors.
     testMethod(findSyntheticMethod(), NestedSynthetic.class, false);
   }
@@ -106,11 +106,11 @@
 
   private static class NestedSynthetic {
     // Accessing this private field will create a synthetic accessor method;
-    private static String dummy;
+    private static String placeholder;
   }
 
-  private static void dummyAccess() {
-    System.out.println(NestedSynthetic.dummy);
+  private static void placeholderAccess() {
+    System.out.println(NestedSynthetic.placeholder);
   }
 
   private static Method findSyntheticMethod() throws Exception {
@@ -33,7 +33,7 @@
     testMethod(getProxyClass(), "run");
 
-    // Find a synthetic method in the dummy inner class. Do not print the name. Javac and Jack
+    // Find a synthetic method in the placeholder inner class. Do not print the name. Javac and Jack
     // disagree on the naming of synthetic accessors.
     testMethod(findSyntheticMethod(), NestedSynthetic.class, false);
diff --git a/test/988-method-trace/gen_srcs.py b/test/988-method-trace/gen_srcs.py
index 225f41b..697b17f 100755
--- a/test/988-method-trace/gen_srcs.py
+++ b/test/988-method-trace/gen_srcs.py
@@ -179,8 +179,8 @@
   def __str__(self):
     return "MethodInfo " + str(self.__dict__)
 
-  def dummy_parameters(self):
-    dummy_values = {
+  def placeholder_parameters(self):
+    placeholder_values = {
      'boolean' : 'false',
      'byte' : '(byte)0',
      'char' : "'x'",
@@ -191,14 +191,14 @@
      'double' : '0.0'
     }
 
-    def object_dummy(name):
+    def object_placeholder(name):
       if name == "java.lang.String":
         return '"hello"'
       else:
         return "(%s)null" %(name)
-    return [ dummy_values.get(param, object_dummy(param)) for param in self.parameters ]
+    return [ placeholder_values.get(param, object_placeholder(param)) for param in self.parameters ]
 
-  def dummy_instance_value(self):
+  def placeholder_instance_value(self):
     return KLASS_INSTANCE_INITIALIZERS.get(self.klass, 'new %s()' %(self.klass))
 
   def is_blacklisted(self):
@@ -257,19 +257,19 @@
     receiver = "instance_" + method_info.klass.replace(".", "_")
   return receiver
 
 # Format a dummy call with dummy method parameters to the requested method.
 def format_call_to(method_info):
-  dummy_args = ", ".join(method_info.dummy_parameters())
+  placeholder_args = ", ".join(method_info.placeholder_parameters())
   receiver = format_receiver_name(method_info)
 
-  return ("%s.%s(%s);" %(receiver, method_info.method_name, dummy_args))
+  return ("%s.%s(%s);" %(receiver, method_info.method_name, placeholder_args))
 
 # Format a static variable with an instance that could be used as the receiver
 # (or None for non-static methods).
 def format_instance_variable(method_info):
   if method_info.staticness == 'static':
     return None
-  return "static %s %s = %s;" %(method_info.klass, format_receiver_name(method_info), method_info.dummy_instance_value())
+  return "static %s %s = %s;" %(method_info.klass, format_receiver_name(method_info), method_info.placeholder_instance_value())
 
 def format_initialize_klass(method_info):
   return "%s.class.toString();" %(method_info.klass)
@@ -257,19 +257,19 @@
   return receiver
 
-# Format a dummy call with dummy method parameters to the requested method.
+# Format a placeholder call with placeholder method parameters to the requested method.
 def format_call_to(method_info):